==> dde-dock_5.4.7.orig.tar.xz: dde-dock-5.4.7/translations/dde-dock_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>%1 eklentisi sistemle uyumlu değil.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth ayarları</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth ayarları</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 bağlandı</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Bağlanıyor...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Klavye düzeni ekle</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Tarih Saat</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-saatlik zaman</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-saatlik zaman</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Zaman ayarları</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Ağı etkinleştir</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Ağı devre dışı bırak</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ay ayarları</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>%1 ögeyi kalıcı olarak silmek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Bu işlem geri alınamaz</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Bilinmeyen aygıt</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Bilinmeyen birim</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Tüm bağı kaldır</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Başlatıcı</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Moda Kipi</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Verimli Kip</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Üst</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Sürekli Göster</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Sürekli Gizle</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Akıllı Gizle</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Kip</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Konum</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Durum</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Eklentiler</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Çoklu Görev Görünümü</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Ayır</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Kablolu bağlantıyı devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Kablolu bağlantıyı etkinleştir</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Kablosuz bağlantıyı devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Kablosuz bağlantıyı etkinleştir</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Ağı devre dışı bırak</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Ağı etkinleştir</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Ay ayarları</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Aygıt devre dışı</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Kablosuz bağlantı: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Kablolu bağlantı: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Bağlı değil</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bağlanıyor</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Bağlı ancak İnternet erişimi yok</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Ağ kablosu takılı değil</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Kablosuz Ağ</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kablolu Ağ</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Bağlantı başarısız</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Ağ</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kablolu Ağ</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kablolu Ağ %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Ekran Klavyesi</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Güç</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Güç ayarları</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>%1 ve azalıyor, %2 dakika kaldı</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>%1 ve azalıyor, %2 saat %3 dakika kaldı</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 ve doluyor, tam dolmaya %2 dakika kaldı</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 ve doluyor, tam dolmaya %2 saat %3 dakika kaldı</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Şarj edildi</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapasite %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>%1 Şarj Oluyor</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapasite %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapasite %1, tam şarjlı</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Masaüstünü Görüntüle</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Ayır</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Güç</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Hesap değiştir</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Güç ayarları</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Aygıt</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Sesi aç</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Sesi kapat</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ses ayarları</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Ses %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Çöp Kutusu</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Çöp Kutusu - %1 dosya</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Çöp Kutusu - %1 dosya</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Boşalt</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Sistem Tepsisi</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Kablosuz Ağ</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Kablosuz Ağ %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.86.1.orig.tar.xz: dde-dock-5.5.86.1/translations/dde-dock_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>%1 eklentisi sistemle uyumlu değil.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Uçak Kipi</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Uçak modu etkin</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Uçak Kipi ayarları</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Uçak modu devre dışı</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Uçak Kipi</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth ayarları</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth ayarları</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 bağlandı</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Bağlanıyor...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Klavye düzeni ekle</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Tarih Saat</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-saatlik zaman</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-saatlik zaman</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Zaman ayarları</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Pazartesi</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Salı</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Çarşamba</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Perşembe</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Cuma</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Cumartesi</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Pazar</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>pazartesi</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sunday</source>
        <translation>pazar</translation>
    </message>
    <message>
        <source>%1year%2month%3day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>%1 ögeyi kalıcı olarak silmek istediğinize emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Bu işlem geri alınamaz</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Bilinmeyen aygıt</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Bilinmeyen birim</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Tüm bağı kaldır</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Başlatıcı</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Güvenli Kipten Çık</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Rıhtım - Güvenli Kip</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Rıhtım güvenli kipte, düzgün şekilde göstermek için lütfen çıkın</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Moda Kipi</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Verimli Kip</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Üst</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Sürekli Göster</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Sürekli Gizle</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Akıllı Gizle</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Kip</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Konum</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Durum</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Rıhtım ayarları</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Boyut</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Çoklu Ekran</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Eklenti Alanı</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Rıhtım&apos;da hangi simgelerin görüneceğini seçin</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Moda Kip</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Verimli Kip</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Kip</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Top</source>
        <translation>Üst</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sol</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Sağ</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Konum</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Gösterilmeyi sürdür</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Gizli tut</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Akıll gizle</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Durum</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Small</source>
        <translation>Küçük</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Büyük</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Rıhtımı Göster</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>İmlecin bulunduğu ekranda</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Sadece ana ekranda</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Çoklu Görev Görünümü</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Ayır</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Ekran Klavyesi</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Güç</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Güç ayarları</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>%1 ve azalıyor, %2 dakika kaldı</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>%1 ve azalıyor, %2 saat %3 dakika kaldı</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 ve doluyor, tam dolmaya %2 dakika kaldı</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 ve doluyor, tam dolmaya %2 saat %3 dakika kaldı</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapasite %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>%1 Şarj Oluyor</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapasite %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapasite %1, tam şarjlı</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Rıhtım</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Kip</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Konum</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Durum</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Boyut</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Rıhtımı Göster</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Eklenti Alanı</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Masaüstünü Görüntüle</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Ayır</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Güç</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Askıya al</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uyut</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilitle</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Oturumu kapat</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Hesap değiştir</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Güç ayarları</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yeniden başlat</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Ses</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Sesi aç</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Sesi kapat</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Ses ayarları</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Ses %1</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Çöp Kutusu</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Çöp Kutusu - %1 dosya</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Çöp Kutusu - %1 dosya</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Çöp Kutusuna Taşı</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Boşalt</translation>
    </message>
</context>
</TS>
